summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJason Madden <jamadden@gmail.com>2018-09-27 07:25:14 -0500
committerJason Madden <jamadden@gmail.com>2018-09-27 07:25:14 -0500
commit2c8cdc48861ef6e42598e1b096e5068cb67d45e1 (patch)
tree861f0016a2c33c4380eb46f627e92594aaf0e22c
parent9c8a74b387d07a7a85669f5813ff249e98818b6e (diff)
downloadzope-configuration-2c8cdc48861ef6e42598e1b096e5068cb67d45e1.tar.gz
Tweak docs for IConfigurationContext.action.
-rw-r--r--src/zope/configuration/interfaces.py29
1 files changed, 19 insertions, 10 deletions
diff --git a/src/zope/configuration/interfaces.py b/src/zope/configuration/interfaces.py
index 45e5ac6..ee66358 100644
--- a/src/zope/configuration/interfaces.py
+++ b/src/zope/configuration/interfaces.py
@@ -98,16 +98,25 @@ class IConfigurationContext(Interface):
"""Record a configuration action
The job of most directives is to compute actions for later
- processing. The action method is used to record those
- actions. The discriminator is used to to find actions that
- conflict. Actions conflict if they have the same
- discriminator. The exception to this is the special case of
- the discriminator with the value None. An actions with a
- discriminator of None never conflicts with other actions. This
- is possible to add an order argument to crudely control the
- order of execution. 'info' is optional source line information,
- 'includepath' is None (the default) or a tuple of include paths for
- this action.
+ processing. The action method is used to record those actions.
+
+ :param callable: The object to call to implement the action.
+ :param tuple args: Arguments to pass to *callable*
+ :param dict kw: Keyword arguments to pass to *callable*
+
+ :param object discriminator: Used to to find actions that conflict.
+ Actions conflict if they have equal discriminators. The
+ exception to this is the special case of the discriminator
+ with the value `None`. An action with a discriminator of `None`
+ never conflicts with other actions.
+
+ :keyword int order: This is possible to add an order argument to crudely control
+ the order of execution.
+
+ :keyword str info: Optional source line information
+
+ :keyword includepath: is None (the default) or a tuple of
+ include paths for this action.
"""
def provideFeature(name):